@@ -18,7 +18,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #                                                                               #
 # This script will compile and run the c examples from source files installed   #
-# in .../share/hdf5_examples/c using h5cc or h5pc.  The order for running       #
+# in /2022Q2/share/examples/hdf5/c using h5cc or h5pc.  The order for running                 #
 # programs with RunTest in the MAIN section below is taken from the Makefile.   #
 # The order is important since some of the test programs use data files created #
 # by earlier test programs.  Any future additions should be placed accordingly. #
@@ -28,10 +28,33 @@
 # Initializations
 EXIT_SUCCESS=0
 EXIT_FAILURE=1
- 
+
+#
+# Try to derive the path to the installation $prefix established
+# by ./configure relative to the examples directory established by
+# ./configure.  If successful, set `prefix_relto_examplesdir` to the
+# relative path.  Otherwise, set `prefix_relto_examplesdir` to the
+# absolute installation $prefix.
+#
+# This script uses the value of `prefix` in the user's environment, if
+# it is set, below.  The content of $() is evaluated in a sub-shell, so
+# if `prefix` is set in the user's environment, the shell statements in
+# $() won't clobbered it.
+#
+prefix_relto_examplesdir=$(
+prefix=/2022Q2
+examplesdir=/2022Q2/share/examples/hdf5
+if [ ${examplesdir##${prefix}/} != ${examplesdir} ]; then
+	echo $(echo ${examplesdir##${prefix}/} | \
+	    sed 's,[^/][^/]*,..,g')
+else
+	echo $prefix
+fi
+)
+
 # Where the tool is installed.
-# default is relative path to installed location of the tools 
-prefix="${prefix:-../../..}"
+# default is relative path to installed location of the tools
+prefix="${prefix:-../${prefix_relto_examplesdir}}"
 PARALLEL=no             # Am I in parallel mode?
 AR="ar"
 RANLIB="ranlib"
@@ -122,6 +145,11 @@ then
         rm h5_extlink &&\
         RunTest h5_elink_unix2win &&\
         rm h5_elink_unix2win &&\
+        OLD_DEBUG_STRING=$HDF5_DEBUG &&\
+        export HDF5_DEBUG="+all +trace +ttimes" &&\
+        RunTest h5_debug_trace &&\
+        HDF5_DEBUG=$OLD_DEBUG_STRING &&\
+        rm h5_debug_trace &&\
         RunTest h5_shared_mesg &&\
         rm h5_shared_mesg &&\
         RunTest h5_vds-eiger &&\
@@ -152,5 +180,5 @@ rm *.h5
 rm -rf red blue u2w
 echo
 
-exit $EXIT_VALUE 
+exit $EXIT_VALUE
 
