@@ -18,7 +18,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #                                                                               #
 # This script will compile and run the c examples from source files installed   #
-# in .../share/examples/hdf5/hl/c using h5cc or h5pc.  The order for running    #
+# in /2022Q2/share/examples/hdf5/hl/c using h5cc or h5pc.  The order for running              #
 # programs with RunTest in the MAIN section below is taken from the Makefile.   #
 # The order is important since some of the test programs use data files created #
 # by earlier test programs.  Any future additions should be placed accordingly. #
@@ -29,9 +29,32 @@
 EXIT_SUCCESS=0
 EXIT_FAILURE=1
 
+#
+# Try to derive the path to the installation $prefix established
+# by ./configure relative to the examples directory established by
+# ./configure.  If successful, set `prefix_relto_examplesdir` to the
+# relative path.  Otherwise, set `prefix_relto_examplesdir` to the
+# absolute installation $prefix.
+#
+# This script uses the value of `prefix` in the user's environment, if
+# it is set, below.  The content of $() is evaluated in a sub-shell, so
+# if `prefix` is set in the user's environment, the shell statements in
+# $() won't clobbered it.
+#
+prefix_relto_examplesdir=$(
+prefix=/2022Q2
+examplesdir=/2022Q2/share/examples/hdf5
+if [ ${examplesdir##${prefix}/} != ${examplesdir} ]; then
+	echo $(echo ${examplesdir##${prefix}/} | \
+	    sed 's,[^/][^/]*,..,g')
+else
+	echo $prefix
+fi
+)
+
 # Where the tool is installed.
 # default is relative path to installed location of the tools
-prefix="${prefix:-../../../..}"
+prefix="${prefix:-../../${prefix_relto_examplesdir}}"
 PARALLEL=no             # Am I in parallel mode?
 AR="ar"
 RANLIB="ranlib"
@@ -115,5 +138,5 @@ rm *.o
 rm *.h5
 echo
 
-exit $EXIT_VALUE 
+exit $EXIT_VALUE
 
